# 程序设计书_灵宝系统

## 功能描述
- 灵宝系统的升星、穿戴、卸下、替换操作

## 名词解析
- 灵宝实例：玩家获得的唯一灵宝实体，可进行升星操作
- 灵宝本体：用于升星消耗的同名材料，可堆叠
- 灵宝碎片：可合成实例或本体的材料
- 专属英雄：与灵宝预设绑定的特定英雄
- 星级阈值：触发技能解锁的关键星级（如3星/6星）

## 核心流程：

### 升星操作：
1. 本地RPC 判断灵宝是否可以升星:
    1.1: 判断条件：
        - 当前星级未达上限
        - 背包中有足够数量的同名灵宝本体
        - 升星所需资源满足配置表要求
    1.2: 可升星处理：
        - 返回true并显示消耗预览
    1.3: 不可升星处理：
        - 返回false并提示具体原因

2. 远端RPC 执行灵宝升星操作:
    2.1: 执行校验：
        - 再次验证本体数量
        - 验证当前星级有效性
        - 校验玩家数据版本号
    2.2: 执行成功处理：
        - 扣除消耗材料
        - 提升灵宝星级
        - 更新属性数值
        - 记录操作日志
        - 推送新的灵宝数据给前端
    2.3: 执行失败处理：
        - 返回错误码（如MATERIAL_INSUFFICIENT/MAX_LEVEL_REACHED）

### 穿戴操作：
1. 本地RPC 判断灵宝是否可以穿戴:
    1.1: 判断条件：
        - 目标英雄未装备其他灵宝
        - 灵宝实例存在且未损坏
        - 玩家等级达到装备要求
    1.2: 可穿戴处理：
        - 返回true并显示属性对比
    1.3: 不可穿戴处理：
        - 返回false并提示限制条件

2. 远端RPC 执行灵宝穿戴操作:
    2.1: 执行校验：
        - 验证英雄状态（是否被锁定）
        - 验证灵宝归属权
        - 检查装备位状态
    2.2: 执行成功处理：
        - 更新英雄装备状态
        - 刷新角色属性
        - 同步装备数据到战斗服务器
        - 推送穿戴成功通知
    2.3: 执行失败处理：
        - 返回错误码（如HERO_LOCKED/EQUIP_SLOT_OCCUPIED）

### 卸下操作：
1. 本地RPC 判断灵宝是否可以卸下:
    1.1: 判断条件：
        - 英雄当前已装备灵宝
        - 灵宝未被战斗锁定
        - 不在副本进行中
    1.2: 可卸下处理：
        - 返回true并显示卸下确认
    1.3: 不可卸下处理：
        - 返回false并提示限制条件

2. 远端RPC 执行灵宝卸下操作:
    2.1: 执行校验：
        - 验证战斗状态
        - 检查操作冷却时间
        - 确认背包空间
    2.2: 执行成功处理：
        - 清除英雄装备状态
        - 计算属性差值
        - 记录操作日志
        - 推送卸下成功通知
    2.3: 执行失败处理：
        - 返回错误码（如BATTLE_LOCKED/INVENTORY_FULL）

### 替换操作：
1. 本地RPC 判断灵宝是否可以替换:
    1.1: 判断条件：
        - 新灵宝与目标英雄兼容
        - 新灵宝星级≥当前装备
        - 满足品质等级要求
    1.2: 可替换处理：
        - 返回true并显示属性对比
    1.3: 不可替换处理：
        - 返回false并提示条件差异

2. 远端RPC 执行灵宝替换操作:
    2.1: 执行校验：
        - 验证新旧灵宝有效性
        - 检查目标英雄状态
        - 确认操作权限
    2.2: 执行成功处理：
        - 执行原子化替换操作
        - 刷新双英雄装备状态
        - 同步数据到所有相关系统
        - 推送替换成功通知
    2.3: 执行失败处理：
        - 回滚操作
        - 返回错误码（如EQUIPMENT_MISMATCH/HERO_STATE_INVALID）

## 特殊规则说明
1. 技能生效规则：
   - 仅当同时满足以下条件时生效：
     a) 装备给专属英雄
     b) 达到技能解锁星级
     c) 不在冷却状态

2. 数据一致性保障：
   - 所有操作需包含以下校验：
     a) 数据版本号校验
     b) 操作时序校验
     c) 事务锁机制

3. 客户端-服务端同步：
   - 采用增量更新协议
   - 重要操作需要二次确认
   - 错误代码包含修复建议
